@@ -32,7 +32,7 @@
 #ifndef _E_CELL_POPUP_H_
 #define _E_CELL_POPUP_H_
 
-#include <libgnomeui/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas.h>
 #include <gal/e-table/e-cell.h>
 
 #define E_CELL_POPUP_TYPE        (e_cell_popup_get_type ())
@@ -82,13 +82,13 @@ struct _ECellPopupView {
 };
 
 
-GtkType  e_cell_popup_get_type           (void);
-ECell   *e_cell_popup_new                (void);
+GtkType    e_cell_popup_get_type		(void);
+ECell     *e_cell_popup_new			(void);
 
 /* Get and set the child ECell. */
-ECell   *e_cell_popup_get_child          (ECellPopup *ecp);
-void     e_cell_popup_set_child          (ECellPopup *ecp,
-					  ECell      *child);
+ECell	  *e_cell_popup_get_child		(ECellPopup	*ecp);
+void       e_cell_popup_set_child		(ECellPopup	*ecp,
+						 ECell		*child);
 
 void     e_cell_popup_set_shown          (ECellPopup *ecp,
 					  gboolean    shown);
