@@ -24,11 +24,11 @@
 #ifndef _E_TABLE_FIELD_CHOOSER_ITEM_H_
 #define _E_TABLE_FIELD_CHOOSER_ITEM_H_
 
-#include <libgnomeui/gnome-canvas.h>
-#include <tree.h>
+#include <libgnomecanvas/gnome-canvas.h>
+#include <libxml/tree.h>
 #include <gal/e-table/e-table-header.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_TABLE_FIELD_CHOOSER_ITEM_TYPE        (e_table_field_chooser_item_get_type ())
 #define E_TABLE_FIELD_CHOOSER_ITEM(o)          (GTK_CHECK_CAST ((o), E_TABLE_FIELD_CHOOSER_ITEM_TYPE, ETableFieldChooserItem))
@@ -70,6 +70,6 @@ typedef struct {
 
 GtkType    e_table_field_chooser_item_get_type (void);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_TABLE_FIELD_CHOOSER_ITEM_H_ */
