@@ -23,11 +23,14 @@
  */
 
 #include <config.h>
+
+#include "e-completion-view.h"
+
 #include <math.h>
 #include <gdk/gdkkeysyms.h>
 #include <gal/e-table/e-table-simple.h>
 #include <gal/e-table/e-table-scrolled.h>
-#include "e-completion-view.h"
+#include <gal/util/e-i18n.h>
 
 enum {
 	E_COMPLETION_VIEW_NONEMPTY,
@@ -452,7 +455,7 @@ e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *key_event, gpoin
 {
 	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
 	gint dir = 0;
-	gboolean key_handled = TRUE, complete_key = FALSE, uncomplete_key = FALSE;
+	gboolean key_handled = TRUE, complete_key = FALSE, uncomplete_key = FALSE, is_space = FALSE;
 
 	/* FIXME: This is totally lame.
 	   The ECompletionView should be able to specify multiple completion/uncompletion keys, or just
@@ -507,23 +510,48 @@ e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *key_event, gpoin
 		break;
 		
 	case GDK_Tab:
-		/* Unbrowse, unhandled. */
-		cv->selection = -1;
-		dir = 0;
-		key_handled = FALSE;
+		/* If our cursor is still up in the entry, move down into
+		   the popup.  Otherwise unbrowse. */
+		if (cv->choices->len > 0) {
+			if (cv->selection < 0) {
+				cv->selection = 0;
+				dir = 0;
+			} else {
+				cv->selection = -1;
+				dir = 0;
+				key_handled = FALSE;
+			}
+		}
 		break;
 
+	case GDK_space:
+	case GDK_KP_Space:
+		is_space = TRUE;
+
 	case GDK_Return:
 	case GDK_KP_Enter:
-	case GDK_space:
-	case GDK_KP_Space:
-		/* Only handle these key presses if we have an active selection;
-		   otherwise, pass them on. */
-		if (cv->selection >= 0) {
+		if (cv->selection < 0) {
+			/* We don't have a selection yet, move to the first selection if there is
+			   more than one option.  If there is only one option, select it automatically. */
+
+			/* Let space pass through. */
+			if (is_space)
+				return FALSE;
+			
+			if (cv->choices->len == 1) {
+				e_completion_view_select (cv, 0);
+				goto stop_emission;
+			} else {
+				cv->selection = 0;
+				dir = 0;
+			}
+
+		} else {
+			/* Our cursor is down in the pop-up, so we make our selection. */
 			e_completion_view_select (cv, cv->selection);
 			goto stop_emission;
 		}
-		return FALSE;
+		break;
 
 	case GDK_Escape:
 		/* Unbrowse hack */
@@ -656,7 +684,7 @@ lost_completion_cb (ECompletion *completion, ECompletionMatch *match, gpointer u
 /*** Table Callbacks ***/
 
 static char *simple_spec = 
-"<ETableSpecification no-headers=\"true\" draw-grid=\"false\" cursor-mode=\"line\" alternating-row-colors=\"false\">"
+"<ETableSpecification no-headers=\"true\" draw-grid=\"false\" cursor-mode=\"line\" alternating-row-colors=\"false\" gettext-domain=\"" E_I18N_DOMAIN "\">"
 "  <ETableColumn model_col=\"0\" _title=\"Node\" expansion=\"1.0\" "
 "         minimum_width=\"16\" resizable=\"true\" cell=\"string\" "
 "         compare=\"string\"/> "
